@@ -5,7 +5,7 @@ use CHI::Stats;
 use strict;
 use warnings;
 
-our $VERSION = '0.35';
+our $VERSION = '0.37';
 
 my ( %final_class_seen, %stats );
 
@@ -82,13 +82,14 @@ sub new {
 
 1;
 
-__END__
+# ABSTRACT: Unified cache handling interface
+
 
 =pod
 
-=head1 NAME
+=head1 VERSION
 
-CHI -- Unified cache handling interface
+version 0.37
 
 =head1 SYNOPSIS
 
@@ -330,7 +331,7 @@ message, the key, and the original raw error message
 
 =back
 
-=back    
+=back
 
 Some drivers will take additional constructor options. For example, the File
 driver takes C<root_dir> and C<depth> options.
@@ -510,8 +511,8 @@ keys, depending on the driver.
 
 The keys may not look the same as they did when passed into L</set>; they may
 have been serialized, utf8 encoded, and/or digested (see L</KEY AND VALUE
-TRANSFORMATION>). However, they may still be passed back into L</get>, L</set>,
-etc. to access the same underlying objects. i.e. the following code is
+TRANSFORMATIONS>). However, they may still be passed back into L</get>,
+L</set>, etc. to access the same underlying objects. i.e. the following code is
 guaranteed to produce all key/value pairs from the cache:
 
   map { ($_, $c->get($_)) } $c->get_keys()
@@ -605,12 +606,12 @@ e.g.
     label
     on_get_error
     on_set_error
-    
+
 =item Standard read-only accessors
 
     namespace
     serializer
-    
+
 =back
 
 =head2 Deprecated methods
@@ -642,11 +643,13 @@ e.g. the following are all valid duration expressions:
     1 minute and ten seconds
     1 hour
 
-=head1 KEY AND VALUE TRANSFORMATION
+=head1 KEY AND VALUE TRANSFORMATIONS
 
 CHI strives to accept arbitrary keys and values for caching regardless of the
 limitations of the underlying driver.
 
+=head2 Key transformations
+
 =over
 
 =item *
@@ -655,12 +658,7 @@ Keys that are references are serialized - see L</key_serializer>.
 
 =item *
 
-Keys with a utf8 flag are utf8 encoded.
-
-=item *
-
-For some drivers (e.g. L<CHI::Driver::File|File>), keys containing special
-characters or whitespace are escaped with URL-like escaping.
+Keys with wide (>255) characters are utf8 encoded.
 
 =item *
 
@@ -669,13 +667,30 @@ L</max_key_length> and L</key_digester>.
 
 =item *
 
+For some drivers (e.g. L<CHI::Driver::File|File>), keys containing special
+characters or whitespace are escaped with URL-like escaping.
+
+=back
+
+Note: All transformations above with the exception of escaping are I<one-way>,
+meaning that CHI does not attempt to undo them when returned from L</get_keys>;
+and I<idempotent>, meaning that applying them a second time has no effect. So
+when you call L</get_keys>, the key you get may not be exactly what you passed
+in, but you'll be able to pass that key in to get the corresponding object.
+
+=head2 Value transformations
+
+=over
+
+=item *
+
 Values which are references are automatically serialized before storing, and
 deserialized after retrieving - see L</serializer>.
 
 =item *
 
-Values with a utf8 flag are are utf8 encoded before storing, and utf8 decoded
-after retrieving.
+Values with their utf8 flag on are utf8 encoded before storing, and utf8
+decoded after retrieving.
 
 =back
 
@@ -1133,24 +1148,23 @@ CHI was originally designed and developed for the Digital Media group of the
 Hearst Corporation, a diversified media company based in New York City.  Many
 thanks to Hearst management for agreeing to this open source release.
 
-=head1 AUTHOR
-
-Jonathan Swartz
-
 =head1 SEE ALSO
 
-L<Cache::Cache|Cache::Cache>, L<Cache::Memcached|Cache::Memcached>,
-L<Cache::FastMmap|Cache::FastMmap>
+L<Cache::Cache|Cache::Cache>
 
-=head1 COPYRIGHT & LICENSE
+=head1 AUTHOR
 
-Copyright (C) 2007 Jonathan Swartz.
+Jonathan Swartz <swartz@pobox.com>
 
-CHI is provided "as is" and without any express or implied warranties,
-including, without limitation, the implied warranties of merchantibility and
-fitness for a particular purpose.
+=head1 COPYRIGHT AND LICENSE
 
-This program is free software; you can redistribute it and/or modify it under
-the same terms as Perl itself.
+This software is copyright (c) 2011 by Jonathan Swartz.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
+
+
+__END__
+
