@@ -1,4 +1,7 @@
 package CHI::Constants;
+BEGIN {
+  $CHI::Constants::VERSION = '0.37';
+}
 use strict;
 use warnings;
 use base qw(Exporter);
@@ -15,27 +18,36 @@ use constant CHI_Max_Time       => 0xffffffff;
 
 1;
 
-__END__
+# ABSTRACT: Internal constants
+
 
 =pod
 
-=head1 NAME
+=head1 VERSION
 
-CHI::Constants -- Internal constants
+version 0.37
 
 =head1 DESCRIPTION
 
 These are constants for internal CHI use.
 
+=head1 SEE ALSO
+
+L<CHI|CHI>
+
 =head1 AUTHOR
 
-Jonathan Swartz
+Jonathan Swartz <swartz@pobox.com>
 
-=head1 COPYRIGHT & LICENSE
+=head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2007 Jonathan Swartz, all rights reserved.
+This software is copyright (c) 2011 by Jonathan Swartz.
 
-This program is free software; you can redistribute it and/or modify it under
-the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
+
+
+__END__
+
