@@ -1,4 +1,7 @@
 package CHI::Driver::Memory;
+BEGIN {
+  $CHI::Driver::Memory::VERSION = '0.37';
+}
 use Carp qw(cluck croak);
 use CHI::Constants qw(CHI_Meta_Namespace);
 use Moose;
@@ -92,13 +95,13 @@ sub discard_policy_lru {
 
 1;
 
-__END__
+
 
 =pod
 
-=head1 NAME
+=head1 VERSION
 
-CHI::Driver::Memory -- In-process memory based cache.
+version 0.37
 
 =head1 SYNOPSIS
 
@@ -151,17 +154,22 @@ policy.
 
 =head1 SEE ALSO
 
-CHI
+L<CHI|CHI>
 
 =head1 AUTHOR
 
-Jonathan Swartz
+Jonathan Swartz <swartz@pobox.com>
 
-=head1 COPYRIGHT & LICENSE
+=head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2007 Jonathan Swartz.
+This software is copyright (c) 2011 by Jonathan Swartz.
 
-This program is free software; you can redistribute it and/or modify it under
-the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
+
+
+__END__
+# ABSTRACT: In-process memory based cache
+
