@@ -1,12 +1,15 @@
 package CHI::Driver::Metacache;
+BEGIN {
+  $CHI::Driver::Metacache::VERSION = '0.37';
+}
 use CHI::Constants qw(CHI_Meta_Namespace);
 use Moose;
 use strict;
 use warnings;
 
-has 'meta_cache'      => ( is => 'ro', builder    => '_build_meta_cache' );
+has 'meta_cache'      => ( is => 'ro', builder => '_build_meta_cache' );
 has 'owner_namespace' => ( is => 'ro', lazy_build => 1 );
-has 'owner_cache'     => ( is => 'ro', weak_ref   => 1 );
+has 'owner_cache'     => ( is => 'ro', weak_ref => 1 );
 
 __PACKAGE__->meta->make_immutable;
 
@@ -53,28 +56,37 @@ sub _prefixed_key {
 
 1;
 
-__END__
+
 
 =pod
 
-=head1 NAME
+=head1 VERSION
 
-CHI::Driver::Metacache
+version 0.37
 
 =head1 SYNOPSIS
 
     $cache->metacache->get($meta_key);
     $cache->metacache->set($meta_key => $value);
 
+=head1 SEE ALSO
+
+L<CHI|CHI>
+
 =head1 AUTHOR
 
-Jonathan Swartz
+Jonathan Swartz <swartz@pobox.com>
 
-=head1 COPYRIGHT & LICENSE
+=head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2007 Jonathan Swartz, all rights reserved.
+This software is copyright (c) 2011 by Jonathan Swartz.
 
-This program is free software; you can redistribute it and/or modify it under
-the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
+
+
+__END__
+# ABSTRACT: metacache for internal CHI use
+
