@@ -1,4 +1,7 @@
 package CHI::Driver::Null;
+BEGIN {
+  $CHI::Driver::Null::VERSION = '0.37';
+}
 use Moose;
 use strict;
 use warnings;
@@ -15,13 +18,13 @@ sub get_namespaces { return () }
 
 1;
 
-__END__
+
 
 =pod
 
-=head1 NAME
+=head1 VERSION
 
-CHI::Driver::Null - nothing is cached
+version 0.37
 
 =head1 SYNOPSIS
 
@@ -36,15 +39,24 @@ CHI::Driver::Null - nothing is cached
 This cache driver implements the full CHI interface without ever actually
 storing items. Useful for disabling caching in an application, for example.
 
+=head1 SEE ALSO
+
+L<CHI|CHI>
+
 =head1 AUTHOR
 
-Jonathan Swartz
+Jonathan Swartz <swartz@pobox.com>
 
-=head1 COPYRIGHT & LICENSE
+=head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2007 Jonathan Swartz.
+This software is copyright (c) 2011 by Jonathan Swartz.
 
-This program is free software; you can redistribute it and/or modify it under
-the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
+
+
+__END__
+# ABSTRACT: nothing is cached
+
