@@ -1,4 +1,7 @@
 package CHI::Driver::Role::Universal;
+BEGIN {
+  $CHI::Driver::Role::Universal::VERSION = '0.37';
+}
 use CHI::Constants qw(CHI_Meta_Namespace);
 use Moose::Role;
 use strict;
@@ -21,24 +24,32 @@ around 'remove' => sub {
 
 1;
 
-__END__
+
 
 =pod
 
-=head1 NAME
+=head1 VERSION
 
-CHI::Driver::Role::Universal -- Universal role applied as the innermost role to
-all CHI drivers
+version 0.37
+
+=head1 SEE ALSO
+
+L<CHI|CHI>
 
 =head1 AUTHOR
 
-Jonathan Swartz
+Jonathan Swartz <swartz@pobox.com>
 
-=head1 COPYRIGHT & LICENSE
+=head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2007 Jonathan Swartz, all rights reserved.
+This software is copyright (c) 2011 by Jonathan Swartz.
 
-This program is free software; you can redistribute it and/or modify it under
-the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
+
+
+__END__
+# ABSTRACT: Universal role applied as the innermost role to all CHI drivers
+
