@@ -2,11 +2,16 @@
 # Recommend Data::Serializer for other serializers, rather than reinventing the wheel.
 #
 package CHI::Serializer::Storable;
-use Mouse;
+BEGIN {
+  $CHI::Serializer::Storable::VERSION = '0.37';
+}
+use Moose;
 use Storable;
 use strict;
 use warnings;
 
+__PACKAGE__->meta->make_immutable;
+
 sub serialize {
     return Storable::freeze( $_[1] );
 }
