@@ -1,8 +1,13 @@
 package CHI::Test::Driver::Readonly;
+BEGIN {
+  $CHI::Test::Driver::Readonly::VERSION = '0.37';
+}
 use Carp;
+use Moose;
 use strict;
 use warnings;
-use base qw(CHI::Driver::Memory);
+extends 'CHI::Driver::Memory';
+__PACKAGE__->meta->make_immutable();
 
 sub store {
     my ( $self, $key, $data ) = @_;
