@@ -1,8 +1,13 @@
 package CHI::Test::Driver::Writeonly;
+BEGIN {
+  $CHI::Test::Driver::Writeonly::VERSION = '0.37';
+}
 use Carp;
 use strict;
 use warnings;
-use base qw(CHI::Driver::Memory);
+use Moose;
+extends 'CHI::Driver::Memory';
+__PACKAGE__->meta->make_immutable();
 
 sub fetch {
     my ( $self, $key ) = @_;
