@@ -1,7 +1,9 @@
 package CHI::Types;
+BEGIN {
+  $CHI::Types::VERSION = '0.37';
+}
 use Carp;
-use CHI::Util qw(parse_duration parse_memory_size);
-use Module::Load::Conditional qw(can_load);
+use CHI::Util qw(can_load parse_duration parse_memory_size);
 use Moose;
 use Moose::Util::TypeConstraints;
 use strict;
@@ -39,10 +41,9 @@ coerce 'CHI::Types::Digester' => from 'Str' => via {
 
 __PACKAGE__->meta->make_immutable;
 
-my $data_serializer_loaded =
-  can_load( modules => { 'Data::Serializer' => undef } );
+my $data_serializer_loaded = can_load('Data::Serializer');
 
-my $digest_loaded = can_load( modules => { 'Digest' => undef } );
+my $digest_loaded = can_load('Digest');
 
 sub _build_data_serializer {
     my ($params) = @_;
@@ -52,7 +53,7 @@ sub _build_data_serializer {
     }
     else {
         croak
-          "Data::Serializer could not be loaded, cannot handle serializer argument";
+          "Could not load Data::Serializer - install Data::Serializer from CPAN to support serializer argument";
     }
 }
 
