@@ -1,4 +1,7 @@
 package CHI::t::Driver::File::DepthZero;
+BEGIN {
+  $CHI::t::Driver::File::DepthZero::VERSION = '0.37';
+}
 use strict;
 use warnings;
 use CHI::Test;
@@ -6,8 +9,6 @@ use File::Temp qw(tempdir);
 use File::Basename qw(dirname);
 use base qw(CHI::t::Driver::File);
 
-my $root_dir;
-
 # Test file driver with zero depth
 
 sub testing_driver_class { 'CHI::Driver::File' }
